<?php
/**
 *
 * @package productive-style
 */

if ( !defined('ABSPATH') ) {
	die();
}

// Registrar Custom Post Type
function productive_style_element_post_type() {
    
    $labels = array(
        'name'                  => _x( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_NAME_PLURAL, 'Post Type General Name', 'productive-style' ),    // Post Type General Name
        'singular_name'         => _x( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_NAME_SINGULAR, 'Post Type Singular Name', 'productive-style' ),     // Post Type Singular Name
        'menu_name'             => __( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_NAME_PLURAL, 'productive-style' ),
        'name_admin_bar'        => __( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_NAME_SINGULAR, 'productive-style' ),
        'archives'              => __( 'Archives', 'productive-style' ),
        'attributes'            => __( 'Attributes', 'productive-style' ),
        'parent_item_colon'     => __( 'Parent Element:', 'productive-style' ),
        'all_items'             => __( 'All Elements', 'productive-style' ),
        'add_new_item'          => __( 'Add New Element', 'productive-style' ),
        'add_new'               => __( 'Add New', 'productive-style' ),
        'new_item'              => __( 'New Element', 'productive-style' ),
        'edit_item'             => __( 'Edit Element', 'productive-style' ),
        'update_item'           => __( 'Update Element', 'productive-style' ),
        'view_item'             => __( 'View Element', 'productive-style' ),
        'view_items'            => __( 'View Elements', 'productive-style' ),
        'search_items'          => __( 'Search Element', 'productive-style' ),
        'not_found'             => __( 'Not found', 'productive-style' ),
        'not_found_in_trash'    => __( 'Not found in Trash', 'productive-style' ),
        'featured_image'        => __( 'Element Image', 'productive-style' ),
        'set_featured_image'    => __( 'Add Element Image', 'productive-style' ),
        'remove_featured_image' => __( 'Remove Element Image', 'productive-style' ),
        'use_featured_image'    => __( 'Use as Main Element Image', 'productive-style' ),
        'insert_into_item'      => __( 'Insert into Element', 'productive-style' ),
        'uploaded_to_this_item' => __( 'Upload to this Element', 'productive-style' ),
        'items_list'            => __( 'Elements list', 'productive-style' ),
        'items_list_navigation' => __( 'Elements list navigation', 'productive-style' ),
        'filter_items_list'     => __( 'Filter Elements', 'productive-style' ),
    );
    $args = array(
        'label'                 => __( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_NAME_SINGULAR, 'productive-style' ),
        'description'           => __( 'Element post type for adding client elements', 'productive-style' ),
        'labels'                => $labels,
        'supports'              => array( 'title', 'editor', 'thumbnail' ),
        'hierarchical'          => true, 
        'public'                => true,
        'show_ui'               => true,
        'show_in_menu'          => true, // hide in admin bar
        'menu_position'         => 9,
        'menu_icon'             => 'dashicons-admin-generic',
        'show_in_admin_bar'     => true, // hide in admin bar
        'show_in_nav_menus'     => true,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => true,
        'show_in_rest'          => true,
        'capability_type'       => 'page',
    );
    register_post_type( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_SLUG, $args ); // limit this to 20 characters, max.

}
add_action( 'init', 'productive_style_element_post_type', 0 );


function productive_style_element_add_meta_box() {
    $args = array(
        //'__back_compact_meta_box' => true,
        '__block_editor_compatible_meta_box' => false,
    );
    add_meta_box('productive_element_id', __( 'Elements Info', 'productive-style' ), 'productive_style_element_add_meta_box_callback', PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_SLUG, 'normal', 'default', $args);
}
add_action( 'add_meta_boxes_' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_SLUG, 'productive_style_element_add_meta_box' );


function productive_style_element_add_meta_box_callback( $post ) {
    $element_post_id = $post->ID;
    $element_meta_object = get_post_meta( $element_post_id, '_element', true );
    $element_icon = '';
    if ( !empty( $element_meta_object['element_icon'] ) ) {
        $element_icon = $element_meta_object['element_icon'];
    }
    $url = '';
    if ( !empty( $element_meta_object['url'] ) ) {
        $url = $element_meta_object['url'];
    }
    $cta_text = '';
    if ( !empty( $element_meta_object['cta_text'] ) ) {
        $cta_text = $element_meta_object['cta_text'];
    }
    wp_nonce_field( 'elementnonce', '_elementnonce' );
    ?>
    <table class="form-table">
        <tr>
            <th>
                <label for="element-element_icon"><?php echo __( 'Icon', 'productive-style' ); ?></label>
                <label class="screen-reader-text" for="element-element_icon"><?php echo __( 'Element Icon', 'productive-style' ); ?></label>
            </th>
            <td>
                <div><input id="element_icon" class="regular-text" aria-required="true" type="text" value="<?php echo esc_attr( $element_icon ); ?>" name="element[element_icon]" class="form-required form-input-tip" /></div>
                <div>
                    <?php echo __( 'Font awesome Icon Code (e.g fa-check)', 'productive-style' ); ?>
                    <a target="_blank" href="https://fontawesome.com/v4/icons">Icons list</a>
                </div>
            </td>
        </tr>
        <tr>
            <th>
                <label for="element-url"><?php echo __( 'CTA Url', 'productive-style' ); ?></label>
                <label class="screen-reader-text" for="element-url"><?php echo __( 'Element Url', 'productive-style' ); ?></label>
            </th>
            <td>
                <div><input id="url" class="regular-text" aria-required="true" type="text" value="<?php echo esc_attr( $url ); ?>" name="element[url]" class="form-required form-input-tip" /></div>
                <div><?php echo __( 'Destination Url for CTA click, starting with http (optional)', 'productive-style' ); ?></div>
            </td>
        </tr>
        <tr>
            <th>
                <label for="element-cta_text"><?php echo __( 'CTA Text', 'productive-style' ); ?></label>
                <label class="screen-reader-text" for="element-cta_text"><?php echo __( 'Element Text', 'productive-style' ); ?></label>
            </th>
            <td>
                <div><input id="cta_text" class="regular-text" aria-required="true" type="text" value="<?php echo esc_attr( $cta_text ); ?>" name="element[cta_text]" class="form-required form-input-tip" /></div>
                <div><?php echo __( 'Text for the CTA button (optional)', 'productive-style' ); ?></div>
            </td>
        </tr>
    </table>
    <?php
}


function productive_style_element_save_meta_box( $post_id, $post ) {
    $element_post_id = $post_id;
    
    if ( !isset( $_POST['_elementnonce'] ) || !wp_verify_nonce( $_POST['_elementnonce'], 'elementnonce' ) ) {
        return $element_post_id;
    }

    $element_post_type_object = get_post_type_object( $post->post_type );
    if ( !current_user_can( $element_post_type_object->cap->edit_post, $element_post_id ) ) {
        return $element_post_id;
    }
    
    if (define( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return $element_post_id;
    }
    
    $this_posts_post_type = $post->post_type;
    if ( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_SLUG != $this_posts_post_type ) {
        return $element_post_id;
    }
    
    if ( isset( $_POST['element'] ) && ! empty( $_POST['element'] ) ) {
        $element_meta_object = array();
        if ( !empty( $_POST['element']['element_icon'] ) ) {
            $element_meta_object['element_icon'] = sanitize_text_field( $_POST['element']['element_icon'] );
        }
        if ( !empty( $_POST['element']['url'] ) ) {
            $element_meta_object['url'] = sanitize_url( $_POST['element']['url'] );
        }
        if ( !empty( $_POST['element']['cta_text'] ) ) {
            $element_meta_object['cta_text'] = sanitize_text_field( $_POST['element']['cta_text'] );
        }
        update_post_meta( $post_id, '_element', $element_meta_object);
    } else {
        delete_post_meta( $post_id, '_element');
    }
    
    return $element_post_id;
}
add_action( 'save_post', 'productive_style_element_save_meta_box', 10, 20 );


function productive_style_element_edit_columns( $columns ) {
    $columns = array(
        'cb'    => '<input type="checkbox" />',
        'title'    => __( 'Title', 'productive-style' ),
        'element-element-icon'    => __( 'Icon', 'productive-style' ),
        'element-url'    => __( 'Url', 'productive-style' ),
        'element-cta-text'    => __( 'CTA Title', 'productive-style' ),
        'taxonomy-element-type'    => __( 'Type', 'productive-style' ),
        'date'    => __( 'Date', 'productive-style' ),
    );
    return $columns;
}
add_filter( 'manage_edit-element_columns', 'productive_style_element_edit_columns' );


function productive_style_element_editable_columns( $column_name, $post_id ) {
    $element_meta_object = get_post_meta( $post_id, '_element', true );
    switch ( $column_name ) {
        case 'element-element-icon':
            if ( !empty( $element_meta_object['element_icon'] ) ) {
                echo esc_attr( $element_meta_object['element_icon'] );
            }
            break;

        case 'element-url':
            if ( !empty( $element_meta_object['url'] ) ) {
                echo '<a target="_blank" href="' . esc_url( $element_meta_object['url'] ) . '">' . esc_url( $element_meta_object['url'] ) . '</a>';
            }
            break;

        case 'element-cta-text':
            if ( !empty( $element_meta_object['cta_text'] ) ) {
                echo esc_attr( $element_meta_object['cta_text'] );
            }
            break;

        default:
            break;
    }
    return $column_name;
}
add_action( 'manage_pages_custom_column', 'productive_style_element_editable_columns', 10, 2 );


function productive_style_element_register_taxonomy() {
    $labels = array(
            'name'              => _x( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_PLURAL, 'Taxonomy General Name', 'productive-style' ),
            'singular_name'     => _x( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_SINGULAR, 'Taxonomy Singular Name', 'productive-style' ),
            'search_items'      => __( 'Search ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_PLURAL, 'productive-style' ),
            'all_items'         => __( 'All ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_PLURAL, 'productive-style' ),
            'view_item'         => __( 'View ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_SINGULAR, 'productive-style' ),
            'parent_item'       => __( 'Parent', 'productive-style' ),
            'parent_item_colon' => __( 'Parent', 'productive-style' ),
            'edit_item'         => __( 'Edit ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_SINGULAR, 'productive-style' ),
            'update_item'       => __( 'Update ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_SINGULAR, 'productive-style' ),
            'add_new_item'      => __( 'Add New ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_SINGULAR, 'productive-style' ),
            'new_item_name'     => __( 'New ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_SINGULAR . ' Name', 'productive-style' ),
            'not_found'         => __( 'No ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_PLURAL . ' Found', 'productive-style' ),
            'back_to_items'     => __( 'Back to ' . PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_PLURAL, 'productive-style' ),
            'menu_name'         => __( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_NAME_PLURAL, 'productive-style' ),
    );
    $args = array(
            'labels'            => $labels,
            'hierarchical'      => true,
            'public'            => true,
            'show_ui'           => true,
            'show_admin_column' => true,
            'query_var'         => true,
            'rewrite'           => array( 'slug' => PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG ),
            'show_in_rest'      => true,
    );
    register_taxonomy( PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG, PRODUCTIVE_STYLE_PLUGIN_ELEMENT_POST_TYPE_SLUG, $args );
    
    productive_style_element_add_taxonomy_items();
    
}
add_action( 'init', 'productive_style_element_register_taxonomy', 0 );


function productive_style_element_add_taxonomy_items() {
    
    $taxonomy_exists = term_exists( 'homepage-element', PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG );
    if ( null == $taxonomy_exists || !$taxonomy_exists || empty( $taxonomy_exists) ) {
        
        $current_plugin_version = get_option( PRODUCTIVE_STYLE_OPTION_VERSION_KEY );
        if ( is_multisite() ) {
            $current_plugin_version = get_site_option( PRODUCTIVE_STYLE_OPTION_VERSION_KEY );
        }
        $features_exists = term_exists( 'features', PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG );
        $services_exists = term_exists( 'services', PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG );
        if( ( $features_exists || $services_exists ) && ( $current_plugin_version == '1.0.1' || $current_plugin_version == '1.0.2' || $current_plugin_version == '1.0.3' ) ) {
            productive_style_taxonomy_upgrade_element_1_0_2();
        } else {
              
            unset($args);
            $args = array(
                'description'   => __( 'Homepage Elements are short USPs on the homepage', 'productive-style' ),
                'slug'          => 'homepage-element',
            );
            wp_insert_term(
                'Homepage Element', 
                PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG, 
                $args
            );

            unset($args);
            $args = array(
                'description'   => __( 'Service Elements describe the services that website operator offers', 'productive-style' ),
                'slug'          => 'service-element',
            );
            wp_insert_term(
                'Service Element', 
                PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG, 
                $args
            );
        }
        
        unset($args);
        $args = array(
            'description'   => __( 'About Elements are used to display information on the About Us page', 'productive-style' ),
            'slug'          => 'about-element',
        );
        wp_insert_term(
            'About Element', 
            PRODUCTIVE_STYLE_PLUGIN_ELEMENT_TAXONOMY_SLUG, 
            $args
        );
        
    }
}