<?php
/**
 *
 * @package productive-style
 */

if ( !defined('ABSPATH') ) {
	die();
}

// Registrar Custom Post Type
function productive_style_service_post_type() {
    
    $labels = array(
        'name'                  => _x( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_NAME_PLURAL, 'Post Type General Name', 'productive-style' ),    // Post Type General Name
        'singular_name'         => _x( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_NAME_SINGULAR, 'Post Type Singular Name', 'productive-style' ),     // Post Type Singular Name
        'menu_name'             => __( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_NAME_PLURAL, 'productive-style' ),
        'name_admin_bar'        => __( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_NAME_SINGULAR, 'productive-style' ),
        'archives'              => __( 'Archives', 'productive-style' ),
        'attributes'            => __( 'Attributes', 'productive-style' ),
        'parent_item_colon'     => __( 'Parent Service:', 'productive-style' ),
        'all_items'             => __( 'All Services', 'productive-style' ),
        'add_new_item'          => __( 'Add New Service', 'productive-style' ),
        'add_new'               => __( 'Add New', 'productive-style' ),
        'new_item'              => __( 'New Service', 'productive-style' ),
        'edit_item'             => __( 'Edit Service', 'productive-style' ),
        'update_item'           => __( 'Update Service', 'productive-style' ),
        'view_item'             => __( 'View Service', 'productive-style' ),
        'view_items'            => __( 'View Services', 'productive-style' ),
        'search_items'          => __( 'Search Service', 'productive-style' ),
        'not_found'             => __( 'Not found', 'productive-style' ),
        'not_found_in_trash'    => __( 'Not found in Trash', 'productive-style' ),
        'featured_image'        => __( 'Service Image', 'productive-style' ),
        'set_featured_image'    => __( 'Add Service Image', 'productive-style' ),
        'remove_featured_image' => __( 'Remove Service Image', 'productive-style' ),
        'use_featured_image'    => __( 'Use as Main Service Image', 'productive-style' ),
        'insert_into_item'      => __( 'Insert into Service', 'productive-style' ),
        'uploaded_to_this_item' => __( 'Upload to this Service', 'productive-style' ),
        'items_list'            => __( 'Services list', 'productive-style' ),
        'items_list_navigation' => __( 'Services list navigation', 'productive-style' ),
        'filter_items_list'     => __( 'Filter Services', 'productive-style' ),
    );
    $args = array(
        'label'                 => __( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_NAME_SINGULAR, 'productive-style' ),
        'description'           => __( 'Service post type for adding client services', 'productive-style' ),
        'labels'                => $labels,
        'supports'              => array( 'title', 'editor', 'thumbnail' ),
        'hierarchical'          => true,
        'public'                => true,
        'show_ui'               => true,
        'show_in_menu'          => true, // hide in admin bar
        'menu_position'         => 10,
        'menu_icon'             => 'dashicons-admin-generic',
        'show_in_admin_bar'     => true, // hide in admin bar
        'show_in_nav_menus'     => true,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => true,
        'show_in_rest'          => true,
        'capability_type'       => 'page',
    );
    register_post_type( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_SLUG, $args ); // limit this to 20 characters, max.

}
add_action( 'init', 'productive_style_service_post_type', 0 );


function productive_style_service_add_meta_box() {
    $args = array(
        //'__back_compact_meta_box' => true,
        '__block_editor_compatible_meta_box' => false,
    );
    add_meta_box('productive_service_id', __( 'Services Info', 'productive-style' ), 'productive_style_service_add_meta_box_callback', PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_SLUG, 'normal', 'default', $args);
}
add_action( 'add_meta_boxes_' . PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_SLUG, 'productive_style_service_add_meta_box' );


function productive_style_service_add_meta_box_callback( $post ) {
    $service_post_id = $post->ID;
    $service_meta_object = get_post_meta( $service_post_id, '_service', true );
    $service_icon = '';
    if ( !empty( $service_meta_object['service_icon'] ) ) {
        $service_icon = $service_meta_object['service_icon'];
    }
    $service_url = '';
    if ( !empty( $service_meta_object['service_url'] ) ) {
        $service_url = $service_meta_object['service_url'];
    }
    $service_cta_text = '';
    if ( !empty( $service_meta_object['service_cta_text'] ) ) {
        $service_cta_text = $service_meta_object['service_cta_text'];
    }
    wp_nonce_field( 'servicenonce', '_servicenonce' );
    ?>
    <table class="form-table">
        <tr>
            <th>
                <label for="service-service_icon"><?php echo __( 'Icon', 'productive-style' ); ?></label>
                <label class="screen-reader-text" for="service-service_icon"><?php echo __( 'Service Icon', 'productive-style' ); ?></label>
            </th>
            <td>
                <div><input id="service_icon" class="regular-text" aria-required="true" type="text" value="<?php echo esc_attr( $service_icon ); ?>" name="service[service_icon]" class="form-required form-input-tip" /></div>
                <div>
                    <?php echo __( 'Font awesome Icon Code (e.g fa-check)', 'productive-style' ); ?>
                    <a target="_blank" href="https://fontawesome.com/v4/icons">Icons list</a>
                </div>
            </td>
        </tr>
        <tr>
            <th>
                <label for="service-service_url"><?php echo __( 'CTA Url', 'productive-style' ); ?></label>
                <label class="screen-reader-text" for="service-service_url"><?php echo __( 'Service Url', 'productive-style' ); ?></label>
            </th>
            <td>
                <div><input id="service_url" class="regular-text" aria-required="true" type="text" value="<?php echo esc_attr( $service_url ); ?>" name="service[service_url]" class="form-required form-input-tip" /></div>
                <div><?php echo __( 'Destination Url for CTA click, starting with http (optional)', 'productive-style' ); ?></div>
            </td>
        </tr>
        <tr>
            <th>
                <label for="service-service_cta_text"><?php echo __( 'CTA Text', 'productive-style' ); ?></label>
                <label class="screen-reader-text" for="service-service_cta_text"><?php echo __( 'Service Text', 'productive-style' ); ?></label>
            </th>
            <td>
                <div><input id="service_cta_text" class="regular-text" aria-required="true" type="text" value="<?php echo esc_attr( $service_cta_text ); ?>" name="service[service_cta_text]" class="form-required form-input-tip" /></div>
                <div><?php echo __( 'Text for the CTA button (optional)', 'productive-style' ); ?></div>
            </td>
        </tr>
    </table>
    <?php
}


function productive_style_service_save_meta_box( $post_id, $post ) {
    $service_post_id = $post_id;
    
    if ( !isset( $_POST['_servicenonce'] ) || !wp_verify_nonce( $_POST['_servicenonce'], 'servicenonce' ) ) {
        return $service_post_id;
    }

    $service_post_type_object = get_post_type_object( $post->post_type );
    if ( !current_user_can( $service_post_type_object->cap->edit_post, $service_post_id ) ) {
        return $service_post_id;
    }
    
    if (define( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return $service_post_id;
    }
    
    $this_posts_post_type = $post->post_type;
    if ( PRODUCTIVE_STYLE_PLUGIN_SERVICE_POST_TYPE_SLUG != $this_posts_post_type ) {
        return $service_post_id;
    }
    
    if ( isset( $_POST['service'] ) && ! empty( $_POST['service'] ) ) {
        $service_meta_object = array();
        if ( !empty( $_POST['service']['service_icon'] ) ) {
            $service_meta_object['service_icon'] = sanitize_text_field( $_POST['service']['service_icon'] );
        }
        if ( !empty( $_POST['service']['service_url'] ) ) {
            $service_meta_object['service_url'] = sanitize_url( $_POST['service']['service_url'] );
        }
        if ( !empty( $_POST['service']['service_cta_text'] ) ) {
            $service_meta_object['service_cta_text'] = sanitize_text_field( $_POST['service']['service_cta_text'] );
        }
        update_post_meta( $post_id, '_service', $service_meta_object);
    } else {
        delete_post_meta( $post_id, '_service');
    }
    
    return $service_post_id;
}
add_action( 'save_post', 'productive_style_service_save_meta_box', 10, 20 );


function productive_style_service_edit_columns( $columns ) {
    $columns = array(
        'cb'    => '<input type="checkbox" />',
        'title'    => __( 'Title', 'productive-style' ),
        'service-service-icon'    => __( 'Icon', 'productive-style' ),
        'service-service-url'    => __( 'Url', 'productive-style' ),
        'service-cta-text'    => __( 'CTA Title', 'productive-style' ),
        'date'    => __( 'Date', 'productive-style' ),
    );
    return $columns;
}
add_filter( 'manage_edit-service_columns', 'productive_style_service_edit_columns' );


function productive_style_service_editable_columns( $column_name, $post_id ) {
    $service_meta_object = get_post_meta( $post_id, '_service', true );
    switch ( $column_name ) {
        case 'service-service-icon':
            if ( !empty( $service_meta_object['service_icon'] ) ) {
                echo esc_attr( $service_meta_object['service_icon'] );
            }
            break;

        case 'service-service-url':
            if ( !empty( $service_meta_object['service_url'] ) ) {
                echo '<a target="_blank" href="' . esc_url( $service_meta_object['service_url'] ) . '">' . esc_url( $service_meta_object['service_url'] ) . '</a>';
            }
            break;

        case 'service-cta-text':
            if ( !empty( $service_meta_object['service_cta_text'] ) ) {
                echo esc_attr( $service_meta_object['service_cta_text'] );
            }
            break;

        default:
            break;
    }
    return $column_name;
}
add_action( 'manage_pages_custom_column', 'productive_style_service_editable_columns', 10, 2 );
